secrets

package
v0.22.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const (
	// ManagerIdentity is the identity used for the Secrets Manager.
	ManagerIdentity = "extension-registry-cache"
	// CAName is the name of the CA secret.
	CAName = "ca-extension-registry-cache"
)

Variables

This section is empty.

Functions

func ConfigsFor

ConfigsFor returns configurations for the secrets manager for the given registry caches services.

func TLSSecretNameForUpstream

func TLSSecretNameForUpstream(upstream string) string

TLSSecretNameForUpstream returns a TLS Secret name for a given upstream.

Types

This section is empty.

Jump to