Documentation
¶
Index ¶
Constants ¶
const ( // ManagerIdentity is the identity used for the Secrets Manager. ManagerIdentity = "extension-registry-cache" // CAName is the name of the CA secret. CAName = "ca-extension-registry-cache" )
Variables ¶
This section is empty.
Functions ¶
func ConfigsFor ¶
func ConfigsFor(services []corev1.Service) []extensionssecretsmanager.SecretConfigWithOptions
ConfigsFor returns configurations for the secrets manager for the given registry caches services.
func TLSSecretNameForUpstream ¶
TLSSecretNameForUpstream returns a TLS Secret name for a given upstream.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.